@@ -57,7 +57,7 @@
 int GyahtzeeAbort = 0;  /* Abort program without playing game */
 
 static char *appID="gtali";
-static char *appName=N_("Gnome Tali");
+static char *appName=N_("GNOME Tali");
 static guint lastHighScore = 0;
 GtkWidget *ScoreList; 
 
@@ -85,6 +85,7 @@ static gint gnome_modify_dice( GtkWidget *widget, GdkEventButton *event,
                                gpointer data );
 static gint gnome_roll_dice( GtkWidget *widget, GdkEvent *event,
                              gpointer data );
+void update_score_state ();
 
 
 void
@@ -104,6 +105,7 @@ CheerWinner(void)
         if ( (winner<NumberOfHumans) && !IsCheater ) {
                 lastHighScore = gnome_score_log((guint)WinningScore, 
                                                 NULL, TRUE);
+		update_score_state ();
                 if (lastHighScore)
                         ShowHighScores();
         }
@@ -349,7 +351,7 @@ say(char *fmt, ...)
 static gint
 about(GtkWidget *widget, gpointer data)
 {
-        GtkWidget *about;
+	static GtkWidget *about = NULL;
         const gchar *authors[] = {
 		N_("Scott Heavner"),
 		N_("Orest Zborowski - Curses Version (C) 1992"),
@@ -362,7 +364,12 @@ about(GtkWidget *widget, gpointer data)
         gchar *translator_credits = _("translator_credits");
 	GdkPixbuf *pixbuf = NULL;
         
-	{
+
+	if (about != NULL) {
+	  	gtk_window_present (GTK_WINDOW(about));
+		return FALSE;
+	}
+        {
 		int i=0;
 		while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
 	}
@@ -372,12 +379,13 @@ about(GtkWidget *widget, gpointer data)
 
         about = gnome_about_new (appName, VERSION,
 				 _("(C) 1998 the Free Software Fundation"),
-				 _("Gnome Tali"),
+				 _("GNOME Tali"),
 				 (const char **)authors,
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
         gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
+	g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
         gtk_widget_show (about);
 	return FALSE;
 }
@@ -385,7 +393,13 @@ about(GtkWidget *widget, gpointer data)
 void
 ShowHighScores(void)
 {
-        gnome_scores_display (appName, appID, NULL, lastHighScore);
+	GtkWidget *dialog;
+
+	dialog = gnome_scores_display (appName, appID, NULL, lastHighScore);
+	if (dialog != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window));
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+	}
 }
 
 static gint 
@@ -478,6 +492,23 @@ LoadDicePixmaps(void)
 	}
 }
 
+void update_score_state ()
+{
+        gchar **names = NULL;
+        gfloat *scores = NULL;
+        time_t *scoretimes = NULL;
+	gint top;
+
+	top = gnome_score_get_notable(appID, NULL, &names, &scores, &scoretimes);
+	if (top > 0) {
+		gtk_widget_set_sensitive (gamemenu[4].widget, TRUE);
+		g_strfreev(names);
+		g_free(scores);
+		g_free(scoretimes);
+	} else {
+		gtk_widget_set_sensitive (gamemenu[4].widget, FALSE);
+	}
+}
 
 static void
 GyahtzeeCreateMainWindow(void)
@@ -556,6 +587,8 @@ GyahtzeeCreateMainWindow(void)
 
         gtk_widget_show(window);
 
+	update_score_state ();
+
 }
 
 
